==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_FindReplaceDialog.h <==
//----------------------------------------------------------------------------
// wxFindReplaceDialog
// extracted from fdrepdlg.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_FINDREPLACEDIALOG_H__
#define __CLASS_WX_FINDREPLACEDIALOG_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxFindReplaceDialog
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_FindReplaceDialog);

//----------------------------------------------------------------------------
// Object declaration for wxFindReplaceDialog
//----------------------------------------------------------------------------
class Object_wx_FindReplaceDialog : public Object_wx_Dialog {
public:
	Gura_DeclareObjectAccessor(wx_FindReplaceDialog)
public:
	inline Object_wx_FindReplaceDialog(wxFindReplaceDialog *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Dialog(Gura_UserClass(wx_FindReplaceDialog), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_FindReplaceDialog(Class *pClass, wxFindReplaceDialog *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Dialog(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_FindReplaceDialog();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxFindReplaceDialog *GetEntity() {
		return dynamic_cast<wxFindReplaceDialog *>(_pEntity);
	}
	inline wxFindReplaceDialog *ReleaseEntity() {
		wxFindReplaceDialog *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxFindReplaceDialog");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_FindReplaceDialog.h <==
//----------------------------------------------------------------------------
// wxFindReplaceDialog
// extracted from fdrepdlg.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_FINDREPLACEDIALOG_H__
#define __CLASS_WX_FINDREPLACEDIALOG_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxFindReplaceDialog
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_FindReplaceDialog);

//----------------------------------------------------------------------------
// Object declaration for wxFindReplaceDialog
//----------------------------------------------------------------------------
class Object_wx_FindReplaceDialog : public Object_wx_Dialog {
public:
	Gura_DeclareObjectAccessor(wx_FindReplaceDialog)
public:
	inline Object_wx_FindReplaceDialog(wxFindReplaceDialog *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Dialog(Gura_UserClass(wx_FindReplaceDialog), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_FindReplaceDialog(Class *pClass, wxFindReplaceDialog *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Dialog(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_FindReplaceDialog();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxFindReplaceDialog *GetEntity() {
		return dynamic_cast<wxFindReplaceDialog *>(_pEntity);
	}
	inline wxFindReplaceDialog *ReleaseEntity() {
		wxFindReplaceDialog *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxFindReplaceDialog");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
